@@ -4,7 +4,8 @@ BiCopIndTest = function(u1,u2)
   if(length(u1) != length(u2)) stop("Lengths of 'u1' and 'u2' do not match.")
   if(length(u1)<2) stop("Number of observations has to be at least 2.")
 
-  tau = cor(u1,u2,method="kendall")
+  #tau = cor(u1,u2,method="kendall")
+  tau = fasttau(u1,u2)
 
 	N = length(u1)
 	f = sqrt((9*N*(N - 1)) / (2*(2*N+ 5))) * abs(tau)
